@@ -43,14 +43,14 @@ sub _result_from_input {
     if ( ref $input eq 'HASH' ) {
         foreach my $field ( $self->sorted_fields ) {
             next if ($field->inactive && !$field->_active);
-            my $field_name = $field->name;
+            my $field_name = $field->name; 
             my $result     = HTML::FormHandler::Field::Result->new(
                 name   => $field_name,
                 parent => $self_result
             );
             $result =
-                $field->_result_from_input( $result, $input->{$field_name},
-                exists $input->{$field_name} );
+                $field->_result_from_input( $result, $input->{$field->input_param || $field_name},
+                exists $input->{$field->input_param || $field_name} );
             $self_result->add_result($result) if $result;
         }
     }
