@@ -24,34 +24,31 @@ Use this module instead of C< use Moose::Role; >
 =cut
 
 Moose::Exporter->setup_import_methods(
-   with_caller => [ 'has_field', 'apply' ],
-   also        => 'Moose::Role',
+    with_caller => [ 'has_field', 'apply' ],
+    also        => 'Moose::Role',
 );
 
-sub init_meta
-{
-   my $class = shift;
+sub init_meta {
+    my $class = shift;
 
-   my %options = @_;
-   Moose::Role->init_meta(%options);
-   my $meta = Moose::Util::MetaRole::apply_metaclass_roles(
-      for_class       => $options{for_class},
-      metaclass_roles => ['HTML::FormHandler::Meta::Role'],
-   );
-   return $meta;
+    my %options = @_;
+    Moose::Role->init_meta(%options);
+    my $meta = Moose::Util::MetaRole::apply_metaclass_roles(
+        for_class       => $options{for_class},
+        metaclass_roles => ['HTML::FormHandler::Meta::Role'],
+    );
+    return $meta;
 }
 
-sub has_field
-{
-   my ( $class, $name, %options ) = @_;
+sub has_field {
+    my ( $class, $name, %options ) = @_;
 
-   $class->meta->add_to_field_list( { name => $name, %options } );
+    $class->meta->add_to_field_list( { name => $name, %options } );
 }
 
-sub apply
-{
-   my ( $class, $arrayref ) = @_;
-   $class->meta->add_to_apply_list( @{$arrayref} );
+sub apply {
+    my ( $class, $arrayref ) = @_;
+    $class->meta->add_to_apply_list( @{$arrayref} );
 }
 
 =head1 AUTHOR
@@ -65,4 +62,5 @@ the same terms as Perl itself.
 
 =cut
 
+use namespace::autoclean;
 1;
